<script setup>
import { computed, reactive, onMounted, onUnmounted, ref } from 'vue';

const props = defineProps({
    modelValue: String,
    width: {
        type: String,
        default: 'fit',
    },
    border: {
        type: Boolean,
        default: true,
    },
    textPosition: {
        type: String,
        default: 'center',
    },
    textarea: {
        type: Boolean,
        default: false,
    },
    readonly: {
        type: Boolean,
        default: false,
    },
    fontWeight: {
        type: String,
        default: 'normal',
    },
});

defineEmits(['update:modelValue']);

const input = ref(null);

onMounted(() => {
    if (input.value.hasAttribute('autofocus')) {
        input.value.focus();
    }
});

defineExpose({ focus: () => input.value.focus() });

const fontWeightClasses = computed(() => {
    return 'font-' + props.fontWeight;
});

const widthStyles = computed(() => {
    if(props.width.includes("rem") || props.width.includes("px")){
        return reactive({
            width: props.width
        });
    }else{
        return '';
    }
});

const widthClasses = computed(() => {
    if(props.width.includes("rem") || props.width.includes("px")){
        return '';
    }else{
        return 'w-' + props.width;
    }
});

const borderClasses = computed(() => {
    if(props.border !== true){
        return 'modal-input-nb';
    }

    if(props.border === true){
        return 'modal-input';
    }
});

const textPositionClasses = computed(() => {
    if(props.textPosition === "center" || props.textPosition === "right" || props.textPosition === "left"){
        return 'text-' + props.textPosition;
    }
});

const readonlyClasses = computed(() => {
    if(props.readonly === true){
        return 'cursor-not-allowed';
    }
});

</script>

<template>
    <input v-if="props.textarea !== true"
        ref="input"
        :class="[widthClasses, borderClasses, textPositionClasses, readonlyClasses, fontWeightClasses]"
        class=""
        :style="[widthStyles]"
        :value="modelValue"
        @input="$emit('update:modelValue', $event.target.value)"
        v-bind="{'readonly' : props.readonly}"
    >
    <textarea v-else-if="props.textarea === true"
        ref="input"
        :class="[widthClasses, borderClasses, textPositionClasses, readonlyClasses, fontWeightClasses]"
        class="h-7 min-h-[28px] px-2"
        :style="[widthStyles]"
        :value="modelValue"
        @input="$emit('update:modelValue', $event.target.value)"
        v-bind="{'readonly' : props.readonly}"
    ></textarea>
</template>